==> mysql-8.0_8.0.42.orig.tar.gz: mysql-8.0.42/plugin/connection_control/connection_delay_api.h <==
/* Copyright (c) 2016, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef CONNECTION_DELAY_API_H
#define CONNECTION_DELAY_API_H

/* Structures/Functions required for information schema table */

extern struct st_mysql_information_schema
    connection_control_failed_attempts_view;
int connection_control_failed_attempts_view_init(void *ptr);

namespace connection_control {

/* constants/variables defined in connection_delay.cc */

extern int64 DEFAULT_THRESHOLD;
extern int64 MIN_THRESHOLD;
extern int64 DISABLE_THRESHOLD;
extern int64 MAX_THRESHOLD;

extern int64 DEFAULT_MAX_DELAY;
extern int64 DEFAULT_MIN_DELAY;
extern int64 MIN_DELAY;
extern int64 MAX_DELAY;

/** Functions being used by connection_control.cc */

class Connection_event_coordinator_services;
class Error_handler;

bool init_connection_delay_event(
    Connection_event_coordinator_services *coordinator,
    Error_handler *error_handler);
void deinit_connection_delay_event();

}  // namespace connection_control
#endif  // !CONNECTION_DELAY_API_H

==> mysql-8.0.18.tar.gz: mysql-8.0.18/plugin/connection_control/connection_delay_api.h <==
/* Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef CONNECTION_DELAY_API_H
#define CONNECTION_DELAY_API_H

/* Structures/Functions requried for information schema table */

extern struct st_mysql_information_schema
    connection_control_failed_attempts_view;
int connection_control_failed_attempts_view_init(void *ptr);

namespace connection_control {

/* constants/variables defined in connection_delay.cc */

extern int64 DEFAULT_THRESHOLD;
extern int64 MIN_THRESHOLD;
extern int64 DISABLE_THRESHOLD;
extern int64 MAX_THRESHOLD;

extern int64 DEFAULT_MAX_DELAY;
extern int64 DEFAULT_MIN_DELAY;
extern int64 MIN_DELAY;
extern int64 MAX_DELAY;

/** Functions being used by connection_control.cc */

class Connection_event_coordinator_services;
class Error_handler;

bool init_connection_delay_event(
    Connection_event_coordinator_services *coordinator,
    Error_handler *error_handler);
void deinit_connection_delay_event();

}  // namespace connection_control
#endif  // !CONNECTION_DELAY_API_H
